@@ -34,7 +34,7 @@
 
 #include "bidi.h"
 
-#include "unictype.h"
+#include <unictype.h>
 
 /* The entire bidi rule could be rewritten into an one-pass approach;
    the implementation below may in the worse case iterate through the
@@ -48,7 +48,7 @@ rtl_ralanenescsetonbnnsm_ok (const uint32_t * label, size_t llen)
 
   for (; llen > 0; label++, llen--)
     {
-      bc = uc_bidi_class (*label);
+      bc = uc_bidi_category (*label);
 
       switch (bc)
 	{
@@ -80,7 +80,7 @@ rtl_ends_ok (const uint32_t * label, size_t llen)
 
   for (p = label + llen - 1; llen > 0; llen--, p--)
     {
-      bc = uc_bidi_class (*p);
+      bc = uc_bidi_category (*p);
       switch (bc)
 	{
 	case UC_BIDI_NSM:
@@ -110,7 +110,7 @@ rtl_enan_ok (const uint32_t * label, size_t llen)
 
   for (p = label + llen - 1; llen > 0; llen--, p--)
     {
-      bc = uc_bidi_class (*p);
+      bc = uc_bidi_category (*p);
       switch (bc)
 	{
 	case UC_BIDI_EN:
@@ -142,7 +142,7 @@ ltr_lenescsetonbnnsm_ok (const uint32_t * label, size_t llen)
 
   for (; llen > 0; label++, llen--)
     {
-      bc = uc_bidi_class (*label);
+      bc = uc_bidi_category (*label);
       switch (bc)
 	{
 	case UC_BIDI_L:
@@ -171,7 +171,7 @@ ltr_ends_ok (const uint32_t * label, size_t llen)
 
   for (p = label + llen - 1; llen > 0; llen--, p--)
     {
-      bc = uc_bidi_class (*p);
+      bc = uc_bidi_category (*p);
       switch (bc)
 	{
 	case UC_BIDI_NSM:
@@ -204,7 +204,7 @@ bidi_p (const uint32_t * label, size_t llen)
 
   for (; llen > 0; label++, llen--)
     {
-      bc = uc_bidi_class (*label);
+      bc = uc_bidi_category (*label);
 
       switch (bc)
 	{
@@ -226,7 +226,7 @@ _idn2_bidi (const uint32_t * label, size_t llen)
   if (!bidi_p (label, llen))
     return IDN2_OK;
 
-  bc = uc_bidi_class (*label);
+  bc = uc_bidi_category (*label);
   switch (bc)
     {
     case UC_BIDI_L:
