@@ -48,6 +48,8 @@ enum
   TEST_CONTEXTO_RULE = 0x0200,
   TEST_UNASSIGNED = 0x0400,
   TEST_BIDI = 0x0800,
+  TEST_TRANSITIONAL = 0x1000,
+  TEST_NONTRANSITIONAL = 0x2000,
 };
 
 extern int _idn2_u8_to_u32_nfc (const uint8_t * src, size_t srclen,
