@@ -38,5 +38,4 @@ extern _IDN2_API int
 _idn2_punycode_decode (size_t input_length,
 		       const char input[],
 		       size_t * output_length,
-		       uint32_t output[],
-		       unsigned char case_flags[]);
+		       uint32_t output[], unsigned char case_flags[]);
